//+------------------------------------------------------------------+ 
//| DJ_Lines.mq4                                                     | 
//| Copyright  2005, MetaQuotes Software Corp.                      | 
//| http://www.metaquotes.net                                        | 
//+------------------------------------------------------------------+ 
/* 
Name := HiLoClose 
Author := hawt and PUMBA 
Link := hawt77@bigmir.net 
*/
#property indicator_chart_window

//---- input parameters5 

extern int   show_comment          = 1; //    (0 - , 1 - ) 
extern int   how_long              = 1000; //    (-1 - ) 
extern color PivotColor            = White;
extern color Resistance1Color      = Red;
extern color Resistance1MidColor   = Red;
extern color Resistance2Color      = Yellow;
extern color Resistance2MidColor   = Yellow;
extern color Resistance3Color      = LimeGreen;
extern color Resistance3MidColor   = LimeGreen;
extern color Support1Color         = Red;
extern color Support1MidColor      = Red;
extern color Support2Color         = Yellow;
extern color Support2MidColor      = Yellow;
extern color Support3Color         = LimeGreen;
extern color Support3MidColor      = LimeGreen;
extern bool  ShowPivots            = true;
extern bool  ShowMidpoints         = true;
extern int   StyleForRegularPivots = STYLE_SOLID;
extern int   StyleForMidpoints     = STYLE_DOT;

//+------------------------------------------------------------------+ 
//| Custom indicator initialization function                         | 
//+------------------------------------------------------------------+ 
//
//
//
//
//

int init()
{
   return(0);
}
int deinit()
{
   for (int i=ObjectsTotal()-1; i>=0; i--)
   {
      string name = ObjectName(i); if (StringSubstr(name,0,8) == "DJ_lines") ObjectDelete(name);
   }
   Comment("");
   return(0);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int start()
{
   int cnt=0; //   
   int begin_bar=0; // ,      
   int prev_day, cur_day; //      
   double day_high=0; //  high 
   double day_low=0; //  low 
   double yesterday_high=0; //     
   double yesterday_low=0; //     
   double yesterday_close=0; //     
   double P, S, R, P1, P2, P3, C1, C2, C3;
   //      - ,   D1 
     if (Period()>=PERIOD_D1) {
      Comment("WARNING: Invalid timeframe! Valid value < D1.");
      return(0);
     }
   //          
     if (how_long==-1) 
     {
      begin_bar=Bars;
      } else {
      begin_bar=how_long;
     }
   //     (0-   , ..      high  low) 
     for(cnt=begin_bar; cnt>=0; cnt--) 
     {
         cur_day=TimeDay(Time[cnt]);
         if (prev_day!=cur_day) 
         {
            yesterday_close = Close[cnt+1];
            yesterday_high  = day_high;
            yesterday_low   = day_low;
            P               = (yesterday_high + yesterday_low + yesterday_close)/3;
            R               = yesterday_high;
            S               = yesterday_low;
            P1              = 2*P - S;
            C1              = 2*P - R;
            P2              = P+ (P1-C1);
            C2              = P- (P1-C1);
            P3              = R+ (2*(P-S));
            C3              = S- (2*(R-P));
         
            // ..   ,   .  .  ()  
            day_high =High[cnt];
            day_low  =Low[cnt];
            //   ,   
            prev_day=cur_day;

            //
            //
            //
            //
            //
            
            datetime startTime = StrToTime(TimeToStr(Time[cnt],TIME_DATE)+" 00:00");
            datetime endTime   = StrToTime(TimeToStr(Time[cnt],TIME_DATE)+" 23:59");
            
               if (ShowPivots)
               {
                  showLine("01",P ,startTime,endTime,PivotColor         ,StyleForRegularPivots,2);
                  showLine("02",P1,startTime,endTime,Resistance1Color   ,StyleForRegularPivots);
                  showLine("04",P2,startTime,endTime,Resistance2Color   ,StyleForRegularPivots);
                  showLine("06",P3,startTime,endTime,Resistance3Color   ,StyleForRegularPivots);
                  showLine("08",C1,startTime,endTime,Support1Color      ,StyleForRegularPivots);
                  showLine("10",C2,startTime,endTime,Support2Color      ,StyleForRegularPivots);
                  showLine("12",C3,startTime,endTime,Support3Color      ,StyleForRegularPivots);
               }                  
               if (ShowMidpoints)
               {
                  showLine("03",(P+P1)/2.0 ,startTime,endTime,Resistance1MidColor,StyleForMidpoints);
                  showLine("05",(P1+P2)/2.0,startTime,endTime,Resistance2MidColor,StyleForMidpoints);
                  showLine("07",(P2+P3)/2.0,startTime,endTime,Resistance3MidColor,StyleForMidpoints);
                  showLine("09",(P+C1)/2.0 ,startTime,endTime,Support1MidColor   ,StyleForMidpoints);
                  showLine("11",(C1+C2)/2.0,startTime,endTime,Support2MidColor   ,StyleForMidpoints);
                  showLine("13",(C2+C3)/2.0,startTime,endTime,Support3MidColor   ,StyleForMidpoints);
               }                  
         }
        
         //    
            day_high=MathMax(day_high, High[cnt]);
            day_low=MathMin(day_low, Low[cnt]);
     }
     if (show_comment==1) 
     {
      P=(yesterday_high + yesterday_low + yesterday_close)/3;
      R=yesterday_high;
      S=yesterday_low;
      P1=2 * P - S;
      C1=2 * P - R;
      P2=P + (P1 - C1);
      C2=P - (P1 - C1);
      P3=R + (2 * (P - S));
      C3=S - (2 * (R - P));
//----
      Comment("Current H=", R, ", L=", S, ", HL/3=", P, " C2=", C2, ", H-L=", (R-S)/Point );
     }
   return(0);
  }
//+------------------------------------------------------------------+

void showLine(string addName,double price, datetime startTime, datetime endTime,color theColor, int theStyle,int width=0)
{
   string name = "DJ_lines"+addName+":"+startTime;
   if (ObjectFind(name)==-1)
       ObjectCreate(name,OBJ_TREND,0,startTime,price,endTime,price);
         ObjectSet(name,OBJPROP_COLOR,theColor);
         ObjectSet(name,OBJPROP_STYLE,theStyle);
         ObjectSet(name,OBJPROP_RAY  ,false);
         ObjectSet(name,OBJPROP_WIDTH,width);
}